@@ -289,13 +289,6 @@ def _build_arg_parser() -> argparse.ArgumentParser:
     parser.add_argument(
         "-j", "--jobs", help="Number of files to process in parallel.", dest="jobs", type=int
     )
-    parser.add_argument(
-        "-k",
-        "--keep-direct-and-as",
-        dest="keep_direct_and_as_imports",
-        action="store_true",
-        help="Turns off default behavior that removes direct imports when as imports exist.",
-    )
     parser.add_argument("--lai", "--lines-after-imports", dest="lines_after_imports", type=int)
     parser.add_argument("--lbt", "--lines-between-types", dest="lines_between_types", type=int)
     parser.add_argument(
@@ -356,14 +349,26 @@ def _build_arg_parser() -> argparse.ArgumentParser:
         "--order-by-type",
         dest="order_by_type",
         action="store_true",
-        help="Order imports by type in addition to alphabetically",
+        help="Order imports by type, which is determined by case, in addition to alphabetically.\n"
+        "\n**NOTE**: type here refers to the implied type from the import name capitalization.\n"
+        ' isort does not do type introspection for the imports. These "types" are simply: '
+        "CONSTANT_VARIABLE, CamelCaseClass, variable_or_function. If your project follows PEP8"
+        " or a related coding standard and has many imports this is a good default, otherwise you "
+        "likely will want to turn it off. From the CLI the `--dont-order-by-type` option will turn "
+        "this off.",
     )
     parser.add_argument(
         "--dt",
         "--dont-order-by-type",
         dest="dont_order_by_type",
         action="store_true",
-        help="Don't order imports by type in addition to alphabetically",
+        help="Don't order imports by type, which is determined by case, in addition to "
+        "alphabetically.\n\n"
+        "**NOTE**: type here refers to the implied type from the import name capitalization.\n"
+        ' isort does not do type introspection for the imports. These "types" are simply: '
+        "CONSTANT_VARIABLE, CamelCaseClass, variable_or_function. If your project follows PEP8"
+        " or a related coding standard and has many imports this is a good default. You can turn "
+        "this on from the CLI using `--order-by-type`.",
     )
     parser.add_argument(
         "-p",
@@ -573,7 +578,26 @@ def _build_arg_parser() -> argparse.ArgumentParser:
         action="store_true",
         help="Tells isort to honor noqa comments to enforce skipping those comments.",
     )
-
+    parser.add_argument(
+        "--remove-redundant-aliases",
+        dest="remove_redundant_aliases",
+        action="store_true",
+        help=(
+            "Tells isort to remove redundant aliases from imports, such as `import os as os`."
+            " This defaults to `False` simply because some projects use these seemingly useless "
+            " aliases to signify intent and change behaviour."
+        ),
+    )
+    parser.add_argument(
+        "--float-to-top",
+        dest="float_to_top",
+        action="store_true",
+        help="Causes all non indented imports to float to the top of the file having its imports "
+        "sorted. *NOTE*: This is a **beta** feature. It currently doesn't work with cimports and "
+        "is gauranteed to run much slower and use much more memory than the default. Still it "
+        "can be a great shortcut for collecting imports every once in a while when you put them "
+        "in the middle of a file.",
+    )
     # deprecated options
     parser.add_argument(
         "--recursive",
@@ -599,10 +623,17 @@ def _build_arg_parser() -> argparse.ArgumentParser:
         "--apply",
         dest="deprecated_flags",
         action="append_const",
-        const="-y",
+        const="--apply",
+        help=argparse.SUPPRESS,
+    )
+    parser.add_argument(
+        "-k",
+        "--keep-direct-and-as",
+        dest="deprecated_flags",
+        action="append_const",
+        const="--keep-direct-and-as",
         help=argparse.SUPPRESS,
     )
-
     return parser
 
 
@@ -644,8 +675,6 @@ def main(argv: Optional[Sequence[str]] = None, stdin: Optional[TextIOWrapper] =
         if os.path.isfile(arguments["settings_path"]):
             arguments["settings_file"] = os.path.abspath(arguments["settings_path"])
             arguments["settings_path"] = os.path.dirname(arguments["settings_file"])
-        elif not os.path.isdir(arguments["settings_path"]):
-            warn(f"settings_path dir does not exist: {arguments['settings_path']}")
         else:
             arguments["settings_path"] = os.path.abspath(arguments["settings_path"])
 
