@@ -132,7 +132,7 @@ def sorted_imports(
             for line in new_section_output:
                 comments = getattr(line, "comments", ())
                 if comments:
-                    if new_section_output and config.ensure_newline_before_comments:
+                    if section_output and config.ensure_newline_before_comments:
                         section_output.append("")
                     section_output.extend(comments)
                 section_output.append(str(line))
@@ -186,6 +186,7 @@ def sorted_imports(
                 in_quote="",
                 index=len(formatted_output),
                 section_comments=config.section_comments,
+                needs_import=False,
             )
             if not should_skip and line.strip():
                 if (
@@ -254,10 +255,10 @@ def _with_from_imports(
         sub_modules = [f"{module}.{from_import}" for from_import in from_imports]
         as_imports = {
             from_import: [
-                f"{from_import} as {as_module}" for as_module in parsed.as_map[sub_module]
+                f"{from_import} as {as_module}" for as_module in parsed.as_map["from"][sub_module]
             ]
             for from_import, sub_module in zip(from_imports, sub_modules)
-            if sub_module in parsed.as_map
+            if sub_module in parsed.as_map["from"]
         }
         if config.combine_as_imports and not ("*" in from_imports and config.combine_star):
             if not config.no_inline_sort:
@@ -266,10 +267,7 @@ def _with_from_imports(
             for from_import in copy.copy(from_imports):
                 if from_import in as_imports:
                     idx = from_imports.index(from_import)
-                    if (
-                        config.keep_direct_and_as_imports
-                        and parsed.imports[section]["from"][module][from_import]
-                    ):
+                    if parsed.imports[section]["from"][module][from_import]:
                         from_imports[(idx + 1) : (idx + 1)] = as_imports.pop(from_import)
                     else:
                         from_imports[idx : (idx + 1)] = as_imports.pop(from_import)
@@ -312,10 +310,7 @@ def _with_from_imports(
                             f"{comments and ';' or config.comment_prefix} " f"{comment}"
                         )
                     if from_import in as_imports:
-                        if (
-                            config.keep_direct_and_as_imports
-                            and parsed.imports[section]["from"][module][from_import]
-                        ):
+                        if parsed.imports[section]["from"][module][from_import]:
                             new_section_output.append(
                                 wrap.line(single_import_line, parsed.line_separator, config)
                             )
@@ -343,10 +338,7 @@ def _with_from_imports(
                     from_comments = parsed.categorized_comments["straight"].get(
                         f"{module}.{from_import}"
                     )
-                    if (
-                        config.keep_direct_and_as_imports
-                        and parsed.imports[section]["from"][module][from_import]
-                    ):
+                    if parsed.imports[section]["from"][module][from_import]:
                         new_section_output.append(
                             with_comments(
                                 from_comments,
@@ -382,8 +374,6 @@ def _with_from_imports(
                     comments = None
 
                 for from_import in copy.copy(from_imports):
-                    if from_import in as_imports and not config.keep_direct_and_as_imports:
-                        continue
                     comment = (
                         parsed.categorized_comments["nested"].get(module, {}).pop(from_import, None)
                     )
@@ -407,8 +397,7 @@ def _with_from_imports(
                 while from_imports and (
                     from_imports[0] not in as_imports
                     or (
-                        config.keep_direct_and_as_imports
-                        and config.combine_as_imports
+                        config.combine_as_imports
                         and parsed.imports[section]["from"][module][from_import]
                     )
                 ):
@@ -486,11 +475,12 @@ def _with_straight_imports(
             continue
 
         import_definition = []
-        if module in parsed.as_map:
-            if config.keep_direct_and_as_imports and parsed.imports[section]["straight"][module]:
+        if module in parsed.as_map["straight"]:
+            if parsed.imports[section]["straight"][module]:
                 import_definition.append(f"{import_type} {module}")
             import_definition.extend(
-                f"{import_type} {module} as {as_import}" for as_import in parsed.as_map[module]
+                f"{import_type} {module} as {as_import}"
+                for as_import in parsed.as_map["straight"][module]
             )
         else:
             import_definition.append(f"{import_type} {module}")
